==> 0.5.11-release.tar.gz: opensim/OpenSim/ApplicationPlugins/Rest/Inventory/IRestHandler.cs <==
/*
 * Copyright (c) Contributors, http://opensimulator.org/
 * See CONTRIBUTORS.TXT for a full list of copyright holders.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *     * Redistributions of source code must retain the above copyright
 *       notice, this list of conditions and the following disclaimer.
 *     * Redistributions in binary form must reproduce the above copyright
 *       notice, this list of conditions and the following disclaimer in the
 *       documentation and/or other materials provided with the distribution.
 *     * Neither the name of the OpenSim Project nor the
 *       names of its contributors may be used to endorse or promote products
 *       derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE DEVELOPERS ``AS IS'' AND ANY
 * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL THE CONTRIBUTORS BE LIABLE FOR ANY
 * DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

using System;
using OpenSim.Framework.Servers;

namespace OpenSim.ApplicationPlugins.Rest.Inventory
{

    /// <remarks>
    /// The handler delegates are not noteworthy. The allocator allows
    /// a given handler to optionally subclass the base RequestData
    /// structure to carry any locally required per-request state
    /// needed.
    /// </remarks>

    public delegate void        RestMethodHandler(RequestData rdata);
    public delegate RequestData RestMethodAllocator(OSHttpRequest request, OSHttpResponse response, string path);

    /// <summary>
    /// This interface represents the boundary between the general purpose
    /// REST plugin handling, and the functionally specific handlers. The
    /// handler knows only to initialize and terminate all such handlers
    /// that it finds. Implementing this interface identifies the class as
    /// a REST handler implementation.
    /// </summary>

    internal interface IRestHandler
    {

        string MsgId     { get; }
        string RequestId { get; }

        void   AddPathHandler(RestMethodHandler mh, string path, RestMethodAllocator ma);
        void AddStreamHandler(string httpMethod, string path, RestMethod method);

    }

}

==> 0.6.5.1-release.tar.gz: opensim/OpenSim/ApplicationPlugins/Rest/Inventory/IRestHandler.cs <==
/*
 * Copyright (c) Contributors, http://opensimulator.org/
 * See CONTRIBUTORS.TXT for a full list of copyright holders.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *     * Redistributions of source code must retain the above copyright
 *       notice, this list of conditions and the following disclaimer.
 *     * Redistributions in binary form must reproduce the above copyright
 *       notice, this list of conditions and the following disclaimer in the
 *       documentation and/or other materials provided with the distribution.
 *     * Neither the name of the OpenSim Project nor the
 *       names of its contributors may be used to endorse or promote products
 *       derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE DEVELOPERS ``AS IS'' AND ANY
 * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL THE CONTRIBUTORS BE LIABLE FOR ANY
 * DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

using OpenSim.Framework.Servers.HttpServer;

namespace OpenSim.ApplicationPlugins.Rest.Inventory
{

    /// <remarks>
    /// The handler delegates are not noteworthy. The allocator allows
    /// a given handler to optionally subclass the base RequestData
    /// structure to carry any locally required per-request state
    /// needed.
    /// </remarks>

    public delegate void        RestMethodHandler(RequestData rdata);
    public delegate RequestData RestMethodAllocator(OSHttpRequest request, OSHttpResponse response, string path);

    /// <summary>
    /// This interface exports the generic plugin-handling services
    /// available to each loaded REST services module (IRest implementation)
    /// </summary>

    internal interface IRestHandler
    {

        string MsgId     { get; }
        string RequestId { get; }

        void   AddPathHandler(RestMethodHandler mh, string path, RestMethodAllocator ma);
        void AddStreamHandler(string httpMethod, string path, RestMethod method);

    }

}
